@@ -37,15 +37,15 @@ class Aliases(object):
 	):
 
 		# get info.
-		current_info, exits = {}, False
+		current_info, exists, edits = {}, False, 0
 		try: current_info = CONFIG["aliases"][alias]
 		except KeyError:
-			exits = False
+			exists = False
 			if not create:
 				return r3sponse.error(f"Alias {alias} does not exist.")
 
 		# check existing config.
-		if exits:
+		if exists:
 			edits, current_info_keys = 0, list(current_info.keys())
 			for info_key, info_value in info.items():
 				do = False
@@ -208,9 +208,9 @@ class Aliases(object):
 		# keys.
 		private_key = syst3m.env.fill(private_key)
 		public_key = syst3m.env.fill(public_key)
-		if not os.path.exists(private_key):
+		if not Files.exists(private_key):
 			return r3sponse.error(f"Private key {private_key} does not exist.")
-		if not os.path.exists(public_key):
+		if not Files.exists(public_key):
 			return r3sponse.error(f"Public key {public_key} does not exist.")
 
 		# info.
@@ -230,7 +230,7 @@ class Aliases(object):
 		json_config["public_port"] = public_port
 		json_config["private_port"] = private_port
 		config += "\n    Port {}".format(port)
-		json_config["user"] = username
+		json_config["username"] = username
 		config += "\n    User {}".format(username)
 		config += "\n    ForwardAgent yes"
 		config += "\n    PubKeyAuthentication yes"
@@ -270,9 +270,9 @@ class Aliases(object):
 			"str":config,
 		})
 	def sync(self):
-		if not os.path.exists(f"{HOME}/.ssh"): os.system(f"mkdir {HOME}/.ssh && chown -R {OWNER}:{GROUP} {HOME}/.ssh && chmod 700 {HOME}/.ssh")
+		if not Files.exists(f"{HOME}/.ssh"): os.system(f"mkdir {HOME}/.ssh && chown -R {OWNER}:{GROUP} {HOME}/.ssh && chmod 700 {HOME}/.ssh")
 		include = f"include ~/.ssht00ls/lib/aliases"
-		if not os.path.exists(f"{HOME}/.ssh/config"): 
+		if not Files.exists(f"{HOME}/.ssh/config"): 
 			Files.save(f"{HOME}/.ssh/config", include)
 			os.system(f"chown {OWNER}:{GROUP} {HOME}/.ssh/config && chmod 770 {HOME}/.ssh/config")
 		if include not in Files.load(f"{HOME}/.ssh/config"):
@@ -282,7 +282,7 @@ class Aliases(object):
 			info = CONFIG["aliases"][alias]
 			if "example.com " not in alias:
 				checked = Dictionary(path=False, dictionary=info).check(default={
-					"user":None,
+					"username":None,
 					"public_ip":None,
 					"private_ip":None,
 					"public_port":None,
