@@ -100,12 +100,12 @@ if CHECKS:
 		sys.exit(1)
 
 	# check lib.
-	if not os.path.exists(f"{SOURCE_PATH}/lib"):
+	if not Files.exists(f"{SOURCE_PATH}/lib"):
 		print("Downloading ssht00ls library.")
 		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && cp -r /tmp/ssht00ls/ssht00ls/lib {SOURCE_PATH}/lib")
 
 	# check usr lib.
-	if not os.path.exists("/usr/local/lib/ssht00ls"):
+	if not Files.exists("/usr/local/lib/ssht00ls"):
 		print("Installing ssht00ls into system library.")
 		os.system(f"rsync -azP {SOURCE_PATH}/ /usr/local/lib/ssht00ls")
 
@@ -115,13 +115,13 @@ if CHECKS:
 		[f"{HOME}/.{ALIAS}/lib", 770],
 		[f"{HOME}/.{ALIAS}/.cache", 770],
 	]:
-		if not os.path.exists(dir): os.system(f"sudo mkdir {dir} && sudo chown {OWNER}:{GROUP} {dir} && sudo chmod {permission} {dir}")
+		if not Files.exists(dir): os.system(f"sudo mkdir {dir} && sudo chown {OWNER}:{GROUP} {dir} && sudo chmod {permission} {dir}")
 
 	# files.
 	CONFIG.check(default={
 		"aliases":{
 			"example.com (key's are optional)":{
-				"user":"administrator",
+				"username":"administrator",
 				"public_ip":"192.168.1.100",
 				"public_port":22,
 				"private_ip":"84.84.123.192",
