@@ -101,7 +101,7 @@ class Key(object):
 			passphrase = '""'
 
 		# create dir.
-		if os.path.exists(directory): 
+		if Files.exists(directory): 
 			response["error"] = f"Key directory [{directory}] already exists."
 			return response
 		else:
@@ -120,7 +120,7 @@ class Key(object):
 
 		# execute.
 		os.system(f'ssh-keygen -q -v -o -a 100 -t ed25519 {passphrase} {identity_file} {comment}')
-		if not os.path.exists(private_key): 
+		if not Files.exists(private_key): 
 			utils.__delete_file_path__(directory, forced=True, sudo=True)
 			response["error"] = f"Failed to generate key [{directory}]."
 			return response
@@ -129,7 +129,7 @@ class Key(object):
 		utils.__set_file_path_permission__(private_key, permission=600, sudo=True)
 		utils.__set_file_path_ownership__(private_key, owner=os.environ.get("USER"), group=None, sudo=True)
 		os.system(f"mv {private_key}.pub {public_key}")
-		if not os.path.exists(public_key): 
+		if not Files.exists(public_key): 
 			utils.__delete_file_path__(directory, forced=True, sudo=True)
 			response["error"] = f"Failed to move private key [{private_key}]."
 			return response
