@@ -45,7 +45,7 @@ def execute(
 	#if not response["success"]: return response
 	#output = response.output
 	# equal to:
-	path = f"/tmp/tmp_script_{Formats.String('').generate()}"
+	path = f"/tmp/tmp_script_{String('').generate()}"
 	Files.save(path, command)
 	try:
 		proc = subprocess.run(
@@ -105,7 +105,7 @@ def check_errors(output):
 		"client_loop: send disconnect: Broken pipe",
 	]:
 		if i in output:
-			e = Formats.String(i+output.split(i)[1].split("\n")[0]).capitalized_word().replace("Client_loop: send disconnect:", "Client loop: send disconnect:").replace("Ssh", "SSH")
+			e = String(i+output.split(i)[1].split("\n")[0]).capitalized_word().replace("Client_loop: send disconnect:", "Client loop: send disconnect:").replace("Ssh", "SSH")
 			while True:
 				if len(e) > 0 and e[len(e)-1] in [" ", "."]: e = e[:-1]
 				elif len(e) > 0 and e[0] in [" "]: e = e[1:]
@@ -113,7 +113,7 @@ def check_errors(output):
 			return r3sponse.error(e+".")
 	return r3sponse.success("The output contains no (default) errors.")
 def test_ssh(alias=None, accept_new_host_keys=True, checks=True):
-	accept_new_host_keys = Formats.Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
+	accept_new_host_keys = Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
 	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {DEFAULT_SSH_OPTIONS} {alias} ' echo "Hello World" ' """)
 	response = check_errors(output)
 	if not response.success:
