@@ -65,7 +65,7 @@ class SSHFS(object):
 			response["error"] = f"Server path [{server_path}] does not exist."
 			return response
 		elif "" == output:
-			if not os.path.exists(client_path):
+			if not Files.exists(client_path):
 				response["error"] = f"Could not connect with server [{alias}]."
 				return response
 			# check success.	
