@@ -53,7 +53,7 @@ class SSync(object):
 		if mode not in ["mount", "sync"]:
 			return r3sponse.error(f"Specified an invalid mode: [{mode}], options: [mount, sync].")
 		cache_path = gfp.absolute(path=gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
-		if mode in ["mount"] and not forced and os.path.exists(path):
+		if mode in ["mount"] and not forced and Files.exists(path):
 			return r3sponse.error(f"Path [{path}] already exists.")
 		elif self.daemons.running(cache_path):
 			return r3sponse.error(f"Path [{path}] is already mounted.")
@@ -76,7 +76,7 @@ class SSync(object):
 			# make sure both dirs exist in the end.
 			# raise error when both dirs do not exist at start.
 			response = ssh.utils.test_ssh_dir(path=remote, alias=alias)
-			remote_exists, local_exists = True, os.path.exists(path)
+			remote_exists, local_exists = True, Files.exists(path)
 			if not response["success"]: 
 				if "does not exist" in response["error"]:
 					remote_exists = False
@@ -86,7 +86,7 @@ class SSync(object):
 				return r3sponse.error(f"Both local and remote directories {path} & {alias}:{remote} do not exist.")
 			if not local_exists:
 				os.system(f"mkdir -p {path}")
-				if not os.path.exists(path): 
+				if not Files.exists(path): 
 					return r3sponse.error(f"Failed to create directory {path}.")
 			if not remote_exists:
 				response = ssh.utils.test_ssh_dir(path=remote, alias=alias, create=True)
@@ -128,7 +128,7 @@ class SSync(object):
 		path = gfp.clean(path)
 		cache_path = gfp.absolute(gfp.clean(path.split(" (d)")[0], remove_last_slash=True))
 		if not self.daemons.running(cache_path):
-			if not os.path.exists(path):
+			if not Files.exists(path):
 				return r3sponse.error(f"Path [{path}] does not exist.")
 			elif not os.path.isdir(path):
 				return r3sponse.error(f"Path [{path}] is not a directory.")
@@ -186,7 +186,7 @@ class SSync(object):
 		# local.
 		else:
 			if checks:
-				if not os.path.exists(path):
+				if not Files.exists(path):
 					return r3sponse.error(f"Path [{path}] does not exist.")
 				elif not os.path.isdir(path):
 					return r3sponse.error(f"Path [{path}] is not a directory.")
