@@ -122,7 +122,7 @@ class Daemon(syst3m.objects.Thread):
 			self.crash(f"ssht00ls daemon ({self.id}): Path [{self.path}] is not running (status: {status}).")
 		if self.log_level >= 0: 
 			loader.mark(f"Checking mountpoint {self.path}")
-		if not os.path.exists(self.path):
+		if not Files.exists(self.path):
 			if self.log_level >= 0: loader.stop(success=False)
 			self.crash(f"ssht00ls daemon ({self.id}): Path [{self.path}] does not exist.")
 		if not os.path.isdir(self.path):
@@ -160,7 +160,7 @@ class Daemon(syst3m.objects.Thread):
 				break
 
 			# if file no longer exists stop daemon.
-			if status == "none" or not os.path.exists(self.path): 
+			if status == "none" or not Files.exists(self.path): 
 				self.crash(f"ssht00ls daemon ({self.id}): Mounted directory [{self.path}] from [{self.alias}:{self.remote}] no longer exists.")
 
 			# sync.
@@ -205,7 +205,7 @@ class Daemon(syst3m.objects.Thread):
 		raise ValueError(error)
 	def unmount(self):
 		if self.mode == "mount":
-			if os.path.exists(self.path):
+			if Files.exists(self.path):
 				response = self.sync(attempts=5, delay=[1, 3, 5, 10, 15])
 				if not response["success"]: return response
 				cache.set(id=self.cache_path, data="*unmounting*", group="daemons")
