@@ -115,15 +115,15 @@ def pull(
 
 	# check base.
 	base = FilePath(path).base(back=1)
-	if not os.path.exists(base): 
+	if not Files.exists(base): 
 		os.system(f"mkdir -p {base}")
-		if not os.path.exists(base): 
+		if not Files.exists(base): 
 			return r3sponse.error(f"Failed to create pull base {base}.")
 		if log_level >= 3:
 			print(f"Created directory {base}.")
 
 	# fix rsync timestamp bug.
-	if empty_directory and directory and not os.path.exists(path):
+	if empty_directory and directory and not Files.exists(path):
 		os.system(f"mkdir -p {path}")
 
 	# options.
