@@ -5,6 +5,16 @@
 from ssht00ls.classes.config import * 
 import os, sys, requests, ast, json, pathlib, glob, string, getpass, django
 
+# save config file safely.
+def save_config_safely():
+	try:
+		CONFIG.save()
+	except KeyboardInterrupt as e:
+		loader = syst3m.console.Loader("&RED&Do not interrupt!&END& Saving ssht00ls config file.")
+		CONFIG.save()
+		loader.stop()
+		raise KeyboardInterrupt(e)
+
 # set a file path permission.
 def __set_file_path_permission__(path, permission=755, sudo=False, recursive=False):
 	if recursive: recursive = "-R "
